@@ -3,9 +3,9 @@ from __future__ import absolute_import, print_function
 
 from suanpan import asyncio
 from suanpan.g import g
-from suanpan.run import cli, env, run
+from suanpan.run import cli, helper, env, run
 
-__version__ = "0.16.22"
+__version__ = "0.16.24"
 
 
 if __name__ == "__main__":
